return {
    { -- gitsigns
        "https://github.com/lewis6991/gitsigns.nvim",
        event = "BufReadPre",
        opts = {
            signs = {
                add = { text = "│" },
                change = { text = "│" },
                delete = { text = "_" },
                topdelete = { text = "‾" },
                changedelete = { text = "~" },
                untracked = { text = "┆" },
            },
            signs_staged = {
                add          = { text = '┃' },
                change       = { text = '┃' },
                delete       = { text = '_' },
                topdelete    = { text = '‾' },
                changedelete = { text = '~' },
                untracked    = { text = '┆' },
            },
            attach_to_untracked = true,
            on_attach = function(buffer)
                local gitsigns = package.loaded.gitsigns

                local function map(mode, l, r, desc)
                    vim.keymap.set(mode, l, r, { buffer = buffer, desc = desc })
                end

                map("n", "]h", gitsigns.next_hunk, "next hunk")
                map("n", "[h", gitsigns.prev_hunk, "prev hunk")

                map("n", "<leader>gb", gitsigns.blame_line, "blame line")
                map("n", "<leader>gB", function() gitsigns.blame_line({ full = true }) end, "full blame!")
                map("n", "<leader>gp", gitsigns.preview_hunk, "look at hunk")
                map("n", "<leader>gS", ":Gitsigns select_hunk<CR>", "select hunk")
                map("n", "<leader>gdd", gitsigns.diffthis, "diff this")

                map("n", "<leader>gsb", gitsigns.stage_buffer, "stage buffer")
                map("n", "<leader>gsh", ":Gitsigns stage_hunk<CR>", "stage hunk (toggle)")
                map("v", '<leader>gsh', function()
                    gitsigns.stage_hunk({vim.fn.line('.'), vim.fn.line('v')})
                end, "stage selected hunk")
                map("n", "<leader>gsu", ":Gitsigns undo_stage_hunk<CR>", "undo last stage hunk")

                map("n", "<leader>grb", "<cmd>Gitsigns reset_buffer<CR>", "reset buffer")
                map("n", "<leader>grh", "<cmd>Gitsigns reset_hunk<CR>", "reset hunk")
                map("v", '<leader>grh', function()
                    gitsigns.reset_hunk({vim.fn.line('.'), vim.fn.line('v')})
                end, "reset selected hunk")

                map("n", "<leader>gtl", "<cmd>Gitsigns toggle_linehl<CR>", "toggle line highlight")
                map("n", "<leader>gtn", "<cmd>Gitsigns toggle_numhl<CR>", "toggle line number highlight")
                map("n", "<leader>gts", "<cmd>Gitsigns toggle_signs<CR>", "toggle signs")
                map("n", "<leader>gtw", "<cmd>Gitsigns toggle_word_diff<CR>", "toggle word diff")
                map("n", "<leader>gtd", "<cmd>Gitsigns toggle_deleted<CR>", "toggle deleted lines")
                map("n", "<leader>gtb", "<cmd>Gitsigns toggle_current_line_blame<CR>", "toggle current line blame")
            end,
        },
    },
    { -- diffview
        "https://github.com/sindrets/diffview.nvim",
        event = "BufReadPre",
        keys = {
            { "<leader>gdo", "<CMD>DiffviewOpen<CR>", desc = "open diffview", },
            { "<leader>gdc", "<CMD>DiffviewClose<CR>", desc = "close diffview", },
        }
    },

    { -- neogit
        "https://github.com/NeogitOrg/neogit",
        event = "BufReadPre",
        dependencies = {
            "https://github.com/nvim-lua/plenary.nvim",
            "https://github.com/sindrets/diffview.nvim",
            "https://github.com/nvim-telescope/telescope.nvim",
        },
        keys = {
            { "<leader>gn", "<CMD>Neogit<CR>", desc = "Neogit", },
        },
        config = true
    },
    { -- git-worktree
        "https://github.com/polarmutex/git-worktree.nvim",
        event = "BufReadPre",
        dependencies = {
            "https://github.com/nvim-lua/plenary.nvim",
            "https://github.com/nvim-telescope/telescope.nvim",
        },
        config = function ()
            require("telescope").load_extension("git_worktree")
        end
    },
    { -- gitgraph
        "https://github.com/isakbm/gitgraph.nvim",
        event = "BufReadPre",
        dependencies = {
            "https://github.com/sindrets/diffview.nvim",
        },
        opts = {
            symbols = {
                merge_commit = 'M',
                commit = '*',
            },
            format = {
                timestamp = '%H:%M:%S %d-%m-%Y',
                fields = { 'hash', 'timestamp', 'author', 'branch_name', 'tag' },
            },
            hooks = {
                -- Check diff of a commit
                on_select_commit = function(commit)
                    vim.notify("DiffviewOpen " .. commit.hash .. '^!')
                    vim.cmd(":DiffviewOpen " .. commit.hash .. '^!')
                end,
                -- Check diff from commit a -> commit b
                on_select_range_commit = function(from, to)
                    vim.notify("DiffviewOpen " .. from.hash .. '~1..' .. to.hash)
                    vim.cmd(":DiffviewOpen " .. from.hash .. '~1..' .. to.hash)
                end,
            },
        },
        keys = {
            {
                "<leader>gl",
                function()
                    require("gitgraph").draw({}, { all = true, max_count = 5000 })
                end,
                desc = "GitGraph - Draw",
            },
        },
    },
}
